@@ -10,31 +10,34 @@ use Search::Query::Clause;
 use Search::Query::Field;
 use Scalar::Util qw( blessed weaken );
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 __PACKAGE__->mk_accessors(
     qw(
-        default_boolop
-        term_regex
-        field_regex
-        op_regex
-        op_nofield_regex
         and_regex
-        or_regex
-        not_regex
-        near_regex
-        range_regex
+        clause_class
+        croak_on_error
+        default_boolop
         default_field
         default_op
+        field_class
+        field_regex
+        fixup
+        near_regex
+        not_regex
+        null_term
+        op_nofield_regex
+        op_regex
+        or_regex
         phrase_delim
         query_class
-        field_class
-        clause_class
         query_class_opts
-        croak_on_error
-        term_expander
+        range_regex
         sloppy
         sloppy_term_regex
+        term_expander
+        term_regex
+
         )
 );
 
@@ -67,6 +70,8 @@ my %DEFAULT = (
     croak_on_error    => 0,             # TODO make it stricter
     sloppy            => 0,
     sloppy_term_regex => qr/[\.\w]+/,
+    fixup             => 0,
+    null_term         => undef,
 );
 
 my %SQPCOMPAT = (
@@ -113,6 +118,10 @@ Search::Query::Parser - convert query strings into query objects
     # a generous mode, overlooking boolean-parser syntax errors
     sloppy              => 0,
     sloppy_term_regex   => qr/[\.\w]+/,
+    fixup               => 0,
+    
+    # if set, this special term indicates a NULL query
+    null_term           => 'NULL',
  );
 
  my $query = $parser->parse('+hello -world now');
@@ -390,6 +399,33 @@ Example:
 
 The regex definition used to match a term when sloppy==1.
 
+=item fixup( 0|1 )
+
+Attempt to fix syntax errors like the lack of a closing parenthesis
+or a missing double-quote. Different than sloppy() which will not
+attempt to fix broken syntax, but should probably be used together 
+if you really do not care about strict syntax checking.
+
+=item null_term
+
+If set to I<term>, the B<null_term> feature will treat field value
+of I<term> as if it was undefined. Example:
+
+ $parser->parse('foo=');     # throws fatal error
+ $parser->null_term('NULL');
+ $parser->parse('foo=NULL'); # field foo has NULL value
+
+This feature is most useful with the SQL dialect, where you might want to 
+find NULL values. Use it like:
+
+ my $parser = Search::Query->parser(
+     dialect    => 'SQL',
+     null_term  => 'NULL'
+ );
+ my $query = $parser->parse('foo!=NULL');
+ print $query;  # prints "foo is not NULL"
+
+
 =back
 
 =head2 init
@@ -884,6 +920,8 @@ sub _parse {
     my $near_regex       = $self->{near_regex};
     my $range_regex      = $self->{range_regex};
     my $clause_class     = $self->{clause_class};
+    my $fixup            = $self->{fixup};
+    my $null_term        = $self->{null_term};
 
     $str =~ s/^\s+//;    # remove leading spaces
 
@@ -943,6 +981,18 @@ LOOP:
                 );
             }
 
+            # fixup mode allows for a partially quoted string.
+            elsif ( $fixup and s/^(")([^"]*?)\s*$// ) {
+                my ( $quote, $val, $proximity ) = ( $1, $2, $3 );
+                $clause = $clause_class->new(
+                    field => $field,
+                    op    => ( $op || $parent_op || ( $field ? ":" : "" ) ),
+                    value => $val,
+                    quote => $quote,
+                    proximity => $proximity
+                );
+            }
+
             # special case for range grouped with () since we do not
             # want the op of record to be the ().
             elsif (s/^\(\s*($term_regex)$range_regex($term_regex)\s*\)\s*//) {
@@ -964,8 +1014,13 @@ LOOP:
                 }
                 $str = $s2;
                 if ( !defined($str) or !( $str =~ s/^\)\s*// ) ) {
-                    $err = "no matching ) ";
-                    last LOOP;
+                    if ( defined($str) and $fixup ) {
+                        $str = ') ' . $str;
+                    }
+                    else {
+                        $err = "no matching ) ";
+                        last LOOP;
+                    }
                 }
 
                 $clause = $clause_class->new(
@@ -989,6 +1044,14 @@ LOOP:
                         value => [ $t1, $t2 ],
                     );
                 }
+                elsif ( $null_term and $term eq $null_term ) {
+                    $clause = $clause_class->new(
+                        field => $field,
+                        op => ( $op || $parent_op || ( $field ? ":" : "" ) ),
+                        value => undef,    # mimic NULL
+                    );
+
+                }
                 else {
 
                     $clause = $clause_class->new(
